@@ -10,9 +10,6 @@ from scipy.interpolate import UnivariateSpline, interp1d, InterpolatedUnivariate
 logger = logging.getLogger('aug_sfutils.mapeq')
 #logger.setLevel(logging.INFO)
 
-def compare_version(a, b):
-    from pkg_resources import parse_version
-    return parse_version(a) > parse_version(b)
 
 def get_nearest_index(tim_eq, tarr):
     """Find nearest time index for a given time.
@@ -432,8 +429,7 @@ def rho2rz(eqm, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
     rho_in = rho2rho(eqm, rhoin, t_in=t_in, \
              coord_in=coord_in, coord_out='Psi', extrapolate=True )
 
-    from matplotlib import _contour
-    import matplotlib
+    import contourpy
 
     nt = len(tarr)
     nr = len(eqm.Rmesh)
@@ -449,23 +445,12 @@ def rho2rz(eqm, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
         jt = index_idx[i]
         Flux = rho_in[jt[0]]
 
-# matplotlib's contour creation
-        try:
-            cgen = _contour.QuadContourGenerator(R, Z, eqm.pfm[:nr, :nz, i].T, None, True, 0)
-        except Exception as e:
-            logger.exception(R.shape, Z.shape, eqm.pfm[:nr, :nz, i].T.shape)
-            raise e 
-
         Rs_t = []
         zs_t = []
 
+        pcgen = contourpy.contour_generator(R, Z, eqm.pfm[:nr, :nz, i].T)
         for jfl, fl in enumerate(Flux):
-            verts = cgen.create_contour(fl)
-            if compare_version(matplotlib.__version__, '3.4.3'):
-                """After MPL ver 3.4.3 the return type is vertices and codes as a list. Prior it was just vertices"""
-                segs = verts[0]
-            else:
-                segs = verts
+            segs = pcgen.lines(fl)
             n_segs = len(segs)
             if n_segs == 0:
                 if fl == eqm.psi0[i]:
